Contributing to OTC Extensions
==============================

OTC Extension are developed as a community effort initiated by
T-Systems International GmbH for the Open Telekom Cloud under an Open
Source license. All code is licensed under the Apache 2.0 license.

We are happily accepting pull requests. Please reach out to the
project to sort out legal code contribution. If you're interested in
contributing to the project, have a look in the `contributors
section`_ of our documentation.

We follow the recommendation of the `OpenStack's workflow`_ for open
source contributions and value the four opens.


Project Hosting Details
-----------------------

Project Documentation
    https://python-otcextensions.readthedocs.io/

Bug tracker
    https://github.com/opentelekomcloud/python-otcextensions/issues

Code Hosting
    https://github.com/opentelekomcloud/python-otcextensions/

.. _contributors section: https://python-otcextensions.readthedocs.io/en/latest/contributor/
.. _OpenStack's workflow: http://docs.openstack.org/infra/manual/developers.html#development-workflow
